"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_ssm_1 = require("aws-ssm");
const aws_log_1 = require("aws-log");
let ssm;
let accessToken;
let siteId;
async function getAccessToken(request) {
    const log = aws_log_1.logger().reloadContext();
    if (request.accessToken) {
        log.info('Got "access_token" from passed in request', {
            netlifySecretSource: "request",
            kind: "accessToken"
        });
        return request.accessToken;
    }
    if (accessToken) {
        log.info('Got "access_token" from SSM cache', {
            netlifySecretSource: "cached",
            kind: "accessToken"
        });
        return accessToken;
    }
    if (!ssm) {
        log.info("Will request Netlify accessToken from SSM", {
            netlifySecretSource: "SSM",
            kind: "accessToken"
        });
        ssm = new aws_ssm_1.SSM();
    }
    try {
        log.info("SSM request sent");
        const secrets = await ssm.modules("netlify");
        log.info("SSM request has returned");
        if (!secrets.netlify.TOKEN) {
            const message = `The access token from SSM came back as empty netlify's TOKEN`;
            log.error(message);
            throw new Error(message);
        }
        siteId = secrets.netlify.SITE_ID;
        accessToken = secrets.netlify.TOKEN;
        return secrets.netlify.TOKEN;
    }
    catch (e) {
        log.error(`SSM Error: ${e.message}`, e);
        throw e;
    }
}
exports.getAccessToken = getAccessToken;
async function getSiteId(request) {
    const log = aws_log_1.logger().reloadContext();
    log.info("getting site ID");
    if (request.siteId) {
        log.info('Got "siteId" from passed-in request', {
            netlifySecretSource: "request",
            kind: "siteId"
        });
        return request.siteId;
    }
    if (siteId) {
        log.info('Got "siteId" from cached SSM value', {
            netlifySecretSource: "cached",
            kind: "siteId"
        });
        return siteId;
    }
    if (!ssm) {
        ssm = new aws_ssm_1.SSM();
    }
    try {
        log.info(`SSM request sent [ ${process.env.AWS_STAGE} / ${process.env.AWS_REGION}]`);
        const secrets = await ssm.modules("netlify");
        log.info('Got "siteId" from from SSM call', {
            netlifySecretSource: "SSM",
            kind: "siteId"
        });
        if (!secrets.netlify.SITE_ID) {
            const message = `The access token from SSM for came back with an empty SITE_ID for netlify`;
            log.error(message);
            throw new Error(message);
        }
        siteId = secrets.netlify.SITE_ID;
        accessToken = secrets.netlify.TOKEN;
        return secrets.netlify.TOKEN;
    }
    catch (e) {
        log.error(`SSM Error: ${e.message}`, e);
        throw e;
    }
}
exports.getSiteId = getSiteId;
